<?php

/**
 * @file
 * Configuration options for the MyFantasyLeague module.
 */

/**
 * Configuration options for the MyFantasyLeague module.
 *
 * @param array $form_state
 *   The current form state.
 * @param object $user
 *   The user object of the user administering MyFantasyLeague.
 */
function myfantasyleague_config(&$form_state, $user = NULL) {
  $uid = 0;
  // Check if the user was passed in.
  if (isset($user)) {
    $uid = $user->uid;
    $verb = 'Your';
  }
  else {
    $verb = 'Global';
  }

  // Get the league info and standings columns from the database.
  $league = myfantasyleague_get_league_info($uid);
  $columns = myfantasyleague_standings_columns($uid);

  $form['#tree'] = TRUE;
  $form['uid'] = array(
    '#type' => 'hidden',
    '#default_value' => $uid,
  );
  $form['league_id'] = array(
    '#type' => 'textfield',
    '#title' => t($verb . ' MyFantasyLeague League ID'),
    '#default_value' => $league['league_id'],
    '#description' => t('To find your league ID, go to your league home page and look at the URL: http://www.myfantasyleague.com/2011/home/xxxxx. The \'xxxxx\' part is your league ID.'),
  );
  $form['year'] = array(
    '#type' => 'textfield',
    '#title' => t($verb . ' MyFantasyLeague League Year'),
    '#default_value' => $league['league_year'],
    '#description' => '',
  );
  $form['columns_title'] = array(
    '#type' => 'item',
    '#title' => t('Standings Columns Order'),
  );
  foreach ($columns as $id => $column) {
    $form['columns'][$id]['name'] = array('#value' => $column['name']);
    $form['columns'][$id]['weight'] = array(
      '#type' => 'weight',
      '#delta' => 50,
      '#default_value' => $column['weight'],
    );
    $form['columns'][$id]['status'] = array(
      '#type' => 'checkbox',
      '#default_value' => $column['status'],
    );
  }
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );

  return $form;
}

/**
 * MyFantasyLeague configuration validator.
 */
function myfantasyleague_config_validate($form, &$form_state) {
  // Make sure the league ID and year are numeric or empty.
  if (!is_numeric($form['league_id']['#value']) && $form['league_id']['#value'] != '') {
    form_error($form['league_id'], t('The League ID must be numeric!'));
  }
  if (!is_numeric($form['year']['#value']) && $form['year']['#value'] != '') {
    form_error($form['year'], t('The year must be numeric!'));
  }
  // Make sure that if either league ID or year are blank, that the other is too.
  if ($form['league_id']['#value'] == '' && $form['year']['#value'] != '') {
    form_error($form['league_id'], t('The league ID must be set.'));
  }
  elseif ($form['league_id']['#value'] != '' && $form['year']['#value'] == '') {
    form_error($form['year'], t('The league year must be set.'));
  }
}

/**
 * MyFantasyLeague configuration submit handler.
 */
function myfantasyleague_config_submit($form, &$form_state) {
  // If the league ID and year aren't set, then delete entries from the database.
  if ($form['league_id']['#value'] == '' && $form['year']['#value'] == '') {
    db_query(
      "DELETE FROM {myfantasyleague_standings_columns} WHERE uid = %d",
      $form['uid']['#value']
    );
    db_query(
      "DELETE FROM {myfantasyleague_users} WHERE uid = %d",
      $form['uid']['#value']
    );
  }
  else {
    // If standings columns are already in database, then update them.
    if (myfantasyleague_standings_columns_set($form['uid']['#value'])) {
      foreach ($form_state['values']['columns'] as $id => $data) {
        if (is_array($data) && isset($data['weight']) && isset($data['status'])) {
          db_query(
            "UPDATE {myfantasyleague_standings_columns} "
            . "SET weight = %d, status = %d "
            . "WHERE uid = %d AND name = '%s'",
            $data['weight'],
            $data['status'],
            $form['uid']['#value'],
            $id
          );
        }
      }
    }
    // Standings columns aren't in database, so insert them.
    else {
      foreach ($form_state['values']['columns'] as $id => $data) {
        if (is_array($data) && isset($data['weight']) && isset($data['status'])) {
          db_query(
            "INSERT INTO {myfantasyleague_standings_columns} (uid, name, status, weight) "
            . "VALUES (%d, '%s', %d, %d)",
            $form['uid']['#value'],
            $id,
            $data['status'],
            $data['weight']
          );
        }
      }
    }

    // Save the league information.
    if (myfantasyleague_get_league_info($form['uid']['#value'])) {
      db_query(
        "UPDATE {myfantasyleague_users} "
        . "SET league_id = %d, league_year = %d "
        . "WHERE uid = %d",
        $form['league_id']['#value'],
        $form['year']['#value'],
        $form['uid']['#value']
      );
    }
    else {
      // Insert a new entry for this user's league.
      db_query(
        "INSERT INTO {myfantasyleague_users} (uid, league_id, league_year) "
        . "VALUES (%d, %d, %d)",
        $form['uid']['#value'],
        $form['league_id']['#value'],
        $form['year']['#value']
      );
    }
  }

  // Clear all cached data since league info might have changed.
  cache_clear_all('myfantasyleague_' . $form['uid']['#value'] . '_', 'cache', TRUE);

  drupal_set_message(t('Saved changes.'));
}

/**
 * Returns HTML for the MyFantasyLeague configuration form.
 *
 * @param array $variables
 *   An associative array containing the form: A render element representing the form.
 *
 * @ingroup themeable
 */
function theme_myfantasyleague_config($variables) {
  $rows = array();
  foreach (element_children($variables['columns']) as $id) {
    $variables['columns'][$id]['weight']['#attributes']['class'] = 'myfantasyleague-standings-columns-order-weight';
    $rows[] = array(
      'data' => array(
        drupal_render($variables['columns'][$id]['name']),
        drupal_render($variables['columns'][$id]['weight']),
        array('data' => drupal_render($variables['columns'][$id]['status']), 'class' => 'checkbox'),
      ),
      'class' => 'draggable',
    );
  }
  $header = array(t('Name'), t('Weight'), array('data' => t('Enabled'), 'class' => 'checkbox'));
  $output = drupal_render($variables['league_id']);
  $output .= drupal_render($variables['year']);
  $output .= drupal_render($variables['columns_title']);
  $output .= theme('table', $header, $rows, array('id' => 'myfantasyleague-standings-columns-order'));
  $output .= drupal_render($variables);

  drupal_add_tabledrag('myfantasyleague-standings-columns-order', 'order', 'sibling', 'myfantasyleague-standings-columns-order-weight');

  return $output;
}
